@@ -213,8 +213,42 @@ mod use_alias_install_if_missing {
 mod use_alias_not_installed {
     test_shell!(Bash, Zsh, Fish, PowerShell; {
         EvalFnmEnv::default()
-          .log_level(Some("error"))
-          .then(WriteFile::new(".node-version", "lts/*"))
-          .then(OutputContains::new(IgnoreErrors::new(GetStderr::new(Call::new("fnm", vec!["use"]))),  "Requested version lts-latest is not currently installed"))
+            .log_level(Some("error"))
+            .then(WriteFile::new(".node-version", "lts/*"))
+            .then(OutputContains::new(IgnoreErrors::new(GetStderr::new(Call::new("fnm", vec!["use"]))),"Requested version lts-latest is not currently installed"))
+    });
+}
+
+mod unalias {
+    test_shell!(Bash, Zsh, Fish, PowerShell; {
+        EvalFnmEnv::default()
+            .then(Call::new("fnm", vec!["install", "11.10.0"]))
+            .then(Call::new("fnm", vec!["install", "8.11.3"]))
+            .then(Call::new("fnm", vec!["alias", "8.11.3", "version8"]))
+            .then(OutputContains::new(Call::new("fnm", vec!["ls"]), "version8"))
+            .then(Call::new("fnm", vec!["unalias", "version8"]))
+            .then(OutputContains::new(IgnoreErrors::new(GetStderr::new(Call::new("fnm", vec!["use", "version8"]))),  "Requested version version8 is not currently installed"))
+    });
+}
+
+mod unalias_error {
+    test_shell!(Bash, Zsh, Fish, PowerShell; {
+        EvalFnmEnv::default()
+            .log_level(Some("error"))
+            .then(OutputContains::new(IgnoreErrors::new(GetStderr::new(Call::new("fnm", vec!["unalias", "lts"]))),  "Requested alias lts not found"))
+    });
+}
+
+mod alias_system {
+    test_shell!(Bash, Zsh, Fish, PowerShell; {
+        EvalFnmEnv::default()
+            .then(Call::new("fnm", vec!["alias", "system", "my_system"]))
+            .then(OutputContains::new(Call::new("fnm", vec!["ls"]), "my_system"))
+            .then(Call::new("fnm", vec!["alias", "system", "default"]))
+            .then(Call::new("fnm", vec!["alias", "my_system", "my_system2"]))
+            .then(OutputContains::new(Call::new("fnm", vec!["ls"]), "my_system2"))
+            .then(OutputContains::new(Call::new("fnm", vec!["use", "my_system"]), "Bypassing fnm"))
+            .then(Call::new("fnm", vec!["unalias", "my_system"]))
+            .then(OutputContains::new(IgnoreErrors::new(GetStderr::new(Call::new("fnm", vec!["use", "my_system"]))),  "Requested version my_system is not currently installed"))
     });
 }
